@@ -8,7 +8,7 @@ from dynamicprompts.constants import DEFAULT_RANDOM
 from dynamicprompts.generators.promptgenerator import PromptGenerator
 from dynamicprompts.parser.config import ParserConfig, default_parser_config
 from dynamicprompts.sampling_context import SamplingContext
-from dynamicprompts.wildcardmanager import WildcardManager
+from dynamicprompts.wildcards import WildcardManager
 
 logger = logging.getLogger(__name__)
 
